==> plasma-framework-5.16.0.zip: plasma-framework-5.16.0/po/lt/scripts/libplasma5/plasmoids.js <==
// First argument must be the same as in .po file, usually capitalized. 2nd and 3rd lowercase unless it is a name.
addDictCases("2D grafikai", "2D grafikų", "šiuos 2D grafikus");
addDictCases("Akys", "akių", "šias akis");
addDictCases("Analoginis laikrodis", "analoginio laikrodžio", "šį analoginį laikrodį");
addDictCases("Asmuo", "asmens", "šį asmenį");
addDictCases("Atminties būsena", "atminties būsenos", "šią atminties būseną");
addDictCases("Baterija ir ryškumas", "baterijos ir ryškumo", "šiuos bateriją ir ryškumą");
addDictCases("CPU apkrovos stebėtojas", "CPU apkrovos stebėtojo","šį CPU apkrovos stebėtoją");
addDictCases("Darbastalis", "darbastalio", "šį darbastalį");
addDictCases("Dvejetainis laikrodis", "dvejetainio laikrodžio", "šį dvejetainį laikrodį");
addDictCases("Garsumas", "garsumo", "šį garsumą");
addDictCases("Greitas pokalbis", "greito pokalbio", "šį greitą pokalbį");
addDictCases("Įvesties metodo skydelis", "įvesties metodo skydelio", "šį įvesties metodo skydelį");
addDictCases("Kalendorius", "kalendoriaus", "šį kalendorių");
addDictCases("Kate sesijos", "Kate sesijų", "šias Kate sesijas");
addDictCases("Konsole profiliai", "Konsole profilių", "šiuos Konsole profilius");
addDictCases("Laikmatis", "laikmačio", "šį laikmatį");
addDictCases("Langų sąrašas", "langų sąrašo", "šį langų sąrašą");
addDictCases("Media grotuvas", "media grotuvo", "šį media grotuvą");
addDictCases("Netikslus laikrodis", "netikslaus laikrodžio", "šį netikslų laikrodį");
addDictCases("Paieška", "paieškos", "šią paiešką");
addDictCases("Penkiolika dalių", "penkiolika dalių", "šias penkiolika dalių");
addDictCases("Pranešimai apie įrenginius", "pranešimų apie įrenginius", "šiuos pranešimus apie įrenginius");
addDictCases("Pranešimai", "pranešimų", "šiuos pranešimus");
addDictCases("Programų meniu", "programų meniu", "šį programų meniu");
addDictCases("Programų paleidiklis", "programų paleidiklio", "šį programų paleidiklį");
addDictCases("Pulto skirtukas", "pulto skirtuko", "šį pulto skirtuką");
addDictCases("Puslapiuotojas", "puslapiuotojo", "šį puslapiuotoją");
addDictCases("Rodyti darbastalį", "rodyti darbastalį", "šį rodyti darbastalį");
addDictCases("Sistemos apkrovos žiūriklis", "sistemos apkrovos žiūriklio", "šį sistemos apkrovos žiūriklį");
addDictCases("Sistemos dėklas", "sistemos dėklo", "šį sistemos dėklą");
addDictCases("Skaičiuotuvas", "skaičiuotuvo", "šį skaičiuotuvą");
addDictCases("Skaitmeninis laikrodis", "skaitmeninio laikrodžio", "šį skaitmeninį laikrodį");
addDictCases("Skydelis", "skydelio", "šį skydelį");
addDictCases("Šiukšliadėžė", "šiukšliadėžės", "šią šiukšliadėžę");
addDictCases("Tik piktogramų užduočių tvarkyklė", "tik piktogramų užduočių tvarkyklės", "šią tik piktogramų užduočių tvarkyklę");
addDictCases("Tinklai", "tinklų", "šiuos tinklus");
addDictCases("Tinklo stebėjimo priemonė", "tinklo stebėjimo priemonės", "šią tinklo stebėjimo priemonę");
addDictCases("Užduočių tvarkyklė", "užduočių tvarkyklės", "šią užduočių tvarkyklę");
addDictCases("Užrakinti/atsijungti", "užrakinti/atsijungti", "šį užrakinti/atsijungti");
addDictCases("Užrašai", "užrašų", "šiuos užrašus");
addDictCases("Veiklos", "veiklų", "šias veiklas");
addDictCases("Veiklų juosta", "veiklų juostos", "šią veiklų juostą");
addDictCases("Ženkliukas", "ženkliuko", "šį ženkliuką");
addDictCases("Žiniatinklio naršyklė", "žiniatinklio naršyklės", "šią žiniatinklio naršyklę");

==> plasma-framework-5.55.0.zip: plasma-framework-5.55.0/po/lt/scripts/libplasma5/plasmoids.js <==
// First argument must be the same as in .po file, usually capitalized. 2nd and 3rd lowercase unless it is a name.
addDictCases("2D grafikai", "2D grafikų", "šiuos 2D grafikus");
addDictCases("Akys", "akių", "šias akis");
addDictCases("Analoginis laikrodis", "analoginio laikrodžio", "šį analoginį laikrodį");
addDictCases("Aplanko rodymas", "aplanko rodymo", "šį aplanko rodymą");
addDictCases("Asmuo", "asmens", "šį asmenį");
addDictCases("Atminties būsena", "atminties būsenos", "šią atminties būseną");
addDictCases("Baterija ir ryškumas", "baterijos ir ryškumo", "šiuos bateriją ir ryškumą");
addDictCases("CPU apkrovos stebėtojas", "CPU apkrovos stebėtojo","šį CPU apkrovos stebėtoją");
addDictCases("Darbalaukis", "darbalaukio", "šį darbalaukį");
addDictCases("Dvejetainis laikrodis", "dvejetainio laikrodžio", "šį dvejetainį laikrodį");
addDictCases("Garsumas", "garsumo", "šį garsumą");
addDictCases("Greitas paleidimas", "greito paleidimo", "šį greitą paleidimą");
addDictCases("Greitas pokalbis", "greito pokalbio", "šį greitą pokalbį");
addDictCases("Iškarpinė", "iškarpinės", "šią iškarpinę");
addDictCases("Įvesties metodo skydelis", "įvesties metodo skydelio", "šį įvesties metodo skydelį");
addDictCases("Jutiklinis kilimėlis", "jutiklinio kilimėlio", "šį jutiklinį kilimėlį")
addDictCases("Kalendorius", "kalendoriaus", "šį kalendorių")
addDictCases("Kate sesijos", "Kate sesijų", "šias Kate sesijas");
addDictCases("KDevelop sesijos", "KDevelop sesijų", "šias KDevelop sesijas");
addDictCases("Komiksų juosta", "komiksų juostos", "šią komiksų juostą");
addDictCases("Konsolės profiliai", "Konsolės profilių", "šiuos Konsolės profilius");
addDictCases("Kūrinių leistuvė", "kūrinių leistuvės", "šią kūrinių leistuvę");
addDictCases("Laikmatis", "laikmačio", "šį laikmatį");
addDictCases("Langų sąrašas", "langų sąrašo", "šį langų sąrašą");
addDictCases("Naudotojų perjungimas", "naudotojų perjungimo", "šį naudotojų perjungimą");
addDictCases("Netikslus laikrodis", "netikslaus laikrodžio", "šį netikslų laikrodį");
addDictCases("Orų prognozė", "orų prognozės", "šią orų prognozę");
addDictCases("Paieška", "paieškos", "šią paiešką");
addDictCases("Penkiolika dalių", "penkiolika dalių", "šias penkiolika dalių");
addDictCases("Pranešimai apie įrenginius", "pranešimų apie įrenginius", "šiuos pranešimus apie įrenginius");
addDictCases("Pranešimai", "pranešimų", "šiuos pranešimus");
addDictCases("Programų meniu", "programų meniu", "šį programų meniu");
addDictCases("Programų paleidiklis", "programų paleidiklio", "šį programų paleidiklį");
addDictCases("Puslapiuotojas", "puslapiuotojo", "šį puslapiuotoją");
addDictCases("Rodyti darbalaukį", "rodyti darbalaukį", "šį rodyti darbalaukį");
addDictCases("Sistemos apkrovos žiūriklis", "sistemos apkrovos žiūriklio", "šį sistemos apkrovos žiūriklį");
addDictCases("Sistemos dėklas", "sistemos dėklo", "šį sistemos dėklą");
addDictCases("Skaičiuoklis", "skaičiuoklio", "šį skaičiuoklį");
addDictCases("Skaitmeninis laikrodis", "skaitmeninio laikrodžio", "šį skaitmeninį laikrodį");
addDictCases("Skydelio skirtukas", "skydelio skirtuko", "šį skydelio skirtuką");
addDictCases("Skydelis", "skydelio", "šį skydelį");
addDictCases("Spalvų parinkiklis", "spalvų parinkiklio", "šį spalvų parinkiklį");
addDictCases("Spausdintuvai", "spausdintuvų", "šiuos spausdintuvus");
addDictCases("Standžiojo disko I/O stebėtojas", "standžiojo disko I/O stebėtojo", "šį standžiojo disko I/O stebėtoją");
addDictCases("Standžiojo disko panaudojimas", "standžiojo disko I/O panaudojimo", "šį standžiojo disko I/O panaudojimą");
addDictCases("Šiukšlinė", "šiukšlinės", "šią šiukšlinę");
addDictCases("Tik ženkliukų užduočių tvarkyklė", "tik ženkliukų užduočių tvarkyklės", "šią tik ženkliukų užduočių tvarkyklę");
addDictCases("Tinklai", "tinklų", "šiuos tinklus");
addDictCases("Tinklo stebėjimo priemonė", "tinklo stebėjimo priemonės", "šią tinklo stebėjimo priemonę");
addDictCases("Užduočių tvarkyklė", "užduočių tvarkyklės", "šią užduočių tvarkyklę");
addDictCases("Užrakinti/atsijungti", "užrakinti/atsijungti", "šį užrakinti/atsijungti");
addDictCases("Užrašai", "užrašų", "šiuos užrašus");
addDictCases("Veiklos", "veiklų", "šias veiklas");
addDictCases("Veiklų juosta", "veiklų juostos", "šią veiklų juostą");
addDictCases("Veiklų perjungimas", "veiklų perjungimo", "šį veiklų perjungimą");
addDictCases("Ženkliukas", "ženkliuko", "šį ženkliuką");
addDictCases("Žiniatinklio naršyklė", "žiniatinklio naršyklės", "šią žiniatinklio naršyklę");
